# this file is @generated
import typing as t
from datetime import datetime

from .common import SvixBaseModel


class ReplayIn(SvixBaseModel):
    since: datetime

    until: t.Optional[datetime] = None



# this file is @generated
import typing as t

from .common import SvixBaseModel


class EndpointTransformationIn(SvixBaseModel):
    code: t.Optional[str] = None

    enabled: t.Optional[bool] = None



# this file is @generated
import typing as t

from pydantic import Field

from .common import SvixBaseModel


class EventTypeFromOpenApi(SvixBaseModel):
    deprecated: bool

    description: str

    feature_flag: t.Optional[str] = Field(default=None, alias="featureFlag")

    group_name: t.Optional[str] = Field(default=None, alias="groupName")
    """The event type group's name"""

    name: str
    """The event type's name"""

    schemas: t.Optional[t.Dict[str, t.Any]] = None



# this file is @generated

from .background_task_status import BackgroundTaskStatus
from .background_task_type import BackgroundTaskType
from .common import SvixBaseModel


class AggregateEventTypesOut(SvixBaseModel):
    id: str

    status: BackgroundTaskStatus

    task: BackgroundTaskType



# this file is @generated
import typing as t

from .common import SvixBaseModel
from .event_type_from_open_api import EventTypeFromOpenApi


class EventTypeImportOpenApiOutData(SvixBaseModel):
    modified: t.List[str]

    to_modify: t.Optional[t.List[EventTypeFromOpenApi]] = None



# this file is @generated
import typing as t

from pydantic import Field

from .background_task_out import BackgroundTaskOut
from .common import SvixBaseModel


class ListResponseBackgroundTaskOut(SvixBaseModel):
    data: t.List[BackgroundTaskOut]

    done: bool

    iterator: str

    prev_iterator: t.Optional[str] = Field(default=None, alias="prevIterator")



# this file is @generated
import typing as t
from datetime import datetime

from pydantic import Field

from .common import SvixBaseModel
from .message_status import MessageStatus


class EndpointMessageOut(SvixBaseModel):
    """A model containing information on a given message plus additional fields on the last attempt for that message."""

    channels: t.Optional[t.List[str]] = None
    """List of free-form identifiers that endpoints can filter by"""

    event_id: t.Optional[str] = Field(default=None, alias="eventId")
    """Optional unique identifier for the message"""

    event_type: str = Field(alias="eventType")
    """The event type's name"""

    id: str
    """The msg's ID"""

    next_attempt: t.Optional[datetime] = Field(default=None, alias="nextAttempt")

    payload: t.Dict[str, t.Any]

    status: MessageStatus

    tags: t.Optional[t.List[str]] = None

    timestamp: datetime



# this file is @generated
import typing as t

from pydantic import Field

from .common import SvixBaseModel


class EventExampleIn(SvixBaseModel):
    event_type: str = Field(alias="eventType")
    """The event type's name"""

    example_index: t.Optional[int] = Field(default=None, alias="exampleIndex")
    """If the event type schema contains an array of examples, chooses which one to send.

    Defaults to the first example. Ignored if the schema doesn't contain an array of examples."""



# this file is @generated
import typing as t
from datetime import datetime

from pydantic import Field

from .common import SvixBaseModel


class ApplicationOut(SvixBaseModel):
    created_at: datetime = Field(alias="createdAt")

    id: str
    """The app's ID"""

    metadata: t.Dict[str, str]

    name: str

    rate_limit: t.Optional[int] = Field(default=None, alias="rateLimit")

    uid: t.Optional[str] = None
    """The app's UID"""

    updated_at: datetime = Field(alias="updatedAt")



# this file is @generated
import typing as t

from pydantic import Field

from .common import SvixBaseModel
from .transformation_template_kind import TransformationTemplateKind


class TemplateIn(SvixBaseModel):
    description: t.Optional[str] = None

    feature_flag: t.Optional[str] = Field(default=None, alias="featureFlag")

    filter_types: t.Optional[t.List[str]] = Field(default=None, alias="filterTypes")

    instructions: t.Optional[str] = None

    instructions_link: t.Optional[str] = Field(default=None, alias="instructionsLink")

    kind: t.Optional[TransformationTemplateKind] = None

    logo: str

    name: str

    transformation: str



# this file is @generated
from datetime import datetime

from pydantic import Field

from .common import SvixBaseModel


class IntegrationOut(SvixBaseModel):
    created_at: datetime = Field(alias="createdAt")

    id: str
    """The integ's ID"""

    name: str

    updated_at: datetime = Field(alias="updatedAt")



# this file is @generated
import typing as t

from pydantic import Field

from .common import SvixBaseModel


class ApplicationIn(SvixBaseModel):
    metadata: t.Optional[t.Dict[str, str]] = None

    name: str

    rate_limit: t.Optional[int] = Field(default=None, alias="rateLimit")

    uid: t.Optional[str] = None
    """Optional unique identifier for the application."""



# this file is @generated
import typing as t
from datetime import datetime

from pydantic import Field

from .common import SvixBaseModel
from .transformation_template_kind import TransformationTemplateKind


class TemplateOut(SvixBaseModel):
    created_at: datetime = Field(alias="createdAt")

    description: str

    feature_flag: t.Optional[str] = Field(default=None, alias="featureFlag")

    filter_types: t.Optional[t.List[str]] = Field(default=None, alias="filterTypes")

    id: str

    instructions: str

    instructions_link: t.Optional[str] = Field(default=None, alias="instructionsLink")

    kind: TransformationTemplateKind

    logo: str

    name: str

    org_id: str = Field(alias="orgId")

    transformation: str

    updated_at: datetime = Field(alias="updatedAt")



# this file is @generated
import typing as t

from pydantic import Field

from .application_out import ApplicationOut
from .common import SvixBaseModel


class ListResponseApplicationOut(SvixBaseModel):
    data: t.List[ApplicationOut]

    done: bool

    iterator: str

    prev_iterator: t.Optional[str] = Field(default=None, alias="prevIterator")



# this file is @generated
import typing as t
from datetime import datetime

from pydantic import Field

from .common import SvixBaseModel


class AppUsageStatsIn(SvixBaseModel):
    app_ids: t.Optional[t.List[str]] = Field(default=None, alias="appIds")
    """Specific app IDs or UIDs to aggregate stats for.

    Note that if none of the given IDs or UIDs are resolved, a 422 response will be given."""

    since: datetime

    until: datetime



# this file is @generated
import typing as t
from datetime import datetime

from pydantic import Field

from .common import SvixBaseModel
from .event_type_out import EventTypeOut
from .template_out import TemplateOut


class EnvironmentOut(SvixBaseModel):
    created_at: datetime = Field(alias="createdAt")

    event_types: t.List[EventTypeOut] = Field(alias="eventTypes")

    settings: t.Dict[str, t.Any]

    transformation_templates: t.List[TemplateOut] = Field(
        alias="transformationTemplates"
    )

    version: t.Optional[int] = None
